import sys

from tools.base_romajis import ROMAJIS


def main():
    basic_romajis = ROMAJIS.copy()

    basic_romajis.sort(key=lambda x: len(x[0]), reverse=True)

    res = f"pub const BASIC_ROMAJI_CHARS: [(&str, &str); {len(basic_romajis)}] = ["
    for hiragana, romaji in basic_romajis:
        res += f'("{hiragana}", "{romaji}"),'
    res += "];"

    print(res)

    print("done.", file=sys.stderr)
    print("do `cargo fmt` for the generated file.", file=sys.stderr)


if __name__ == '__main__':
    main()



from successive_romaji._lowlevel import try_read, parse_hiragana, parse_hiragana_with_buf
__all__ = ["try_read", "parse_hiragana", "parse_hiragana_with_buf"]

if __name__ == '__main__':
    print(parse_hiragana_with_buf("あああ", "a"))



from typing import Optional, Literal, TypeAlias

Romaji: TypeAlias = tuple[str, str]


def try_read(hiragana: str, romaji: str) -> Optional[tuple[str, str, Romaji]]:
    ...


def parse_hiragana(hiragana: str) -> list[Romaji]:
    ...


def parse_hiragana_with_buf(hiragana: str, romaji: str) -> tuple[Literal["Writing", "Completed"], list[Romaji], tuple[str, str, str], list[Romaji]]:
    ...
